diff --git a/core/lib/Drupal/Component/Utility/Random.php b/core/lib/Drupal/Component/Utility/Random.php
index 356eefd..8d29e6b 100644
--- a/core/lib/Drupal/Component/Utility/Random.php
+++ b/core/lib/Drupal/Component/Utility/Random.php
@@ -267,16 +267,16 @@ public function paragraphs($paragraph_count = 12) {
    *
    * @param string $destination
    *   The absolute file path where the image should be stored.
-   * @param int $min_resolution
-   * @param int $max_resolution
+   * @param int $min_dimensions
+   * @param int $max_dimensions
    *
    * @return string
    *   Path to image file.
    */
-  public function image($destination, $min_resolution, $max_resolution) {
+  public function image($destination, $min_dimensions, $max_dimensions) {
     $extension = pathinfo($destination, PATHINFO_EXTENSION);
-    $min = explode('x', $min_resolution);
-    $max = explode('x', $max_resolution);
+    $min = explode('x', $min_dimensions);
+    $max = explode('x', $max_dimensions);
 
     $width = rand((int) $min[0], (int) $max[0]);
     $height = rand((int) $min[1], (int) $max[1]);
diff --git a/core/modules/editor/src/Form/EditorImageDialog.php b/core/modules/editor/src/Form/EditorImageDialog.php
index e3d592a..4767d35 100644
--- a/core/modules/editor/src/Form/EditorImageDialog.php
+++ b/core/modules/editor/src/Form/EditorImageDialog.php
@@ -71,7 +71,7 @@ public function buildForm(array $form, FormStateInterface $form_state, FilterFor
       '#upload_validators' => array(
         'file_validate_extensions' => array('gif png jpg jpeg'),
         'file_validate_size' => array($max_filesize),
-        'file_validate_image_resolution' => array($max_dimensions),
+        'file_validate_image_dimensions' => array($max_dimensions),
       ),
       '#required' => TRUE,
     );
diff --git a/core/modules/file/file.field.inc b/core/modules/file/file.field.inc
index 7ec9d09..9639bcf 100644
--- a/core/modules/file/file.field.inc
+++ b/core/modules/file/file.field.inc
@@ -185,9 +185,9 @@ function template_preprocess_file_upload_help(&$variables) {
     $descriptions[] = t('Allowed types: @extensions.', array('@extensions' => $upload_validators['file_validate_extensions'][0]));
   }
 
-  if (isset($upload_validators['file_validate_image_resolution'])) {
-    $max = $upload_validators['file_validate_image_resolution'][0];
-    $min = $upload_validators['file_validate_image_resolution'][1];
+  if (isset($upload_validators['file_validate_image_dimensions'])) {
+    $max = $upload_validators['file_validate_image_dimensions'][0];
+    $min = $upload_validators['file_validate_image_dimensions'][1];
     if ($min && $max && $min == $max) {
       $descriptions[] = t('Images must be exactly <strong>@size</strong> pixels.', array('@size' => $max));
     }
diff --git a/core/modules/file/file.module b/core/modules/file/file.module
index 0bc0584..5fef105 100644
--- a/core/modules/file/file.module
+++ b/core/modules/file/file.module
@@ -399,6 +399,17 @@ function file_validate_is_image(FileInterface $file) {
 }
 
 /**
+ * Backwards compatibility wrapper for file_validate_image_dimensions().
+ *
+ * @deprecated in Drupal 8.0.0, will be removed for Drupal 9.0.0.
+ *
+ * @see file_validate_image_dimensions()
+ */
+function file_validate_image_resolution(FileInterface $file, $maximum_dimensions = 0, $minimum_dimensions = 0) {
+  return file_validate_image_dimensions($file, $maximum_dimensions, $minimum_dimensions);
+}
+
+/**
  * Verifies that image dimensions are within the specified maximum and minimum.
  *
  * Non-image files will be ignored. If a image toolkit is available the image
@@ -421,7 +432,7 @@ function file_validate_is_image(FileInterface $file) {
  *
  * @see hook_file_validate()
  */
-function file_validate_image_resolution(FileInterface $file, $maximum_dimensions = 0, $minimum_dimensions = 0) {
+function file_validate_image_dimensions(FileInterface $file, $maximum_dimensions = 0, $minimum_dimensions = 0) {
   $errors = array();
 
   // Check first that the file is an image.
diff --git a/core/modules/image/config/schema/image.schema.yml b/core/modules/image/config/schema/image.schema.yml
index 00268ef..e5a9c41 100644
--- a/core/modules/image/config/schema/image.schema.yml
+++ b/core/modules/image/config/schema/image.schema.yml
@@ -94,12 +94,12 @@ field.field_settings.image:
   type: base_file_field_field_settings
   label: 'Image settings'
   mapping:
-    max_resolution:
+    max_dimensions:
       type: string
-      label: 'Maximum image resolution'
-    min_resolution:
+      label: 'Maximum image dimensions'
+    min_dimensions:
       type: string
-      label: 'Minimum image resolution'
+      label: 'Minimum image dimensions'
     alt_field:
       type: boolean
       label: 'Enable Alt field'
diff --git a/core/modules/image/src/Tests/ImageFieldValidateTest.php b/core/modules/image/src/Tests/ImageFieldValidateTest.php
index 025c65e..9f9e0cf 100644
--- a/core/modules/image/src/Tests/ImageFieldValidateTest.php
+++ b/core/modules/image/src/Tests/ImageFieldValidateTest.php
@@ -8,21 +8,21 @@
 namespace Drupal\image\Tests;
 
 /**
- * Tests validation functions such as min/max resolution.
+ * Tests validation functions such as min/max dimensions.
  *
  * @group image
  */
 class ImageFieldValidateTest extends ImageFieldTestBase {
   /**
-   * Test min/max resolution settings.
+   * Test min/max dimensions settings.
    */
-  function testResolution() {
+  function testDimensions() {
     $field_name = strtolower($this->randomMachineName());
-    $min_resolution = 50;
-    $max_resolution = 100;
+    $min_dimensions = 50;
+    $max_dimensions = 100;
     $field_settings = array(
-      'max_resolution' => $max_resolution . 'x' . $max_resolution,
-      'min_resolution' => $min_resolution . 'x' . $min_resolution,
+      'max_dimensions' => $max_dimensions . 'x' . $max_dimensions,
+      'min_dimensions' => $min_dimensions . 'x' . $min_dimensions,
     );
     $this->createImageField($field_name, 'article', array(), $field_settings);
 
@@ -33,10 +33,10 @@ function testResolution() {
     $image_factory = $this->container->get('image.factory');
     foreach ($this->drupalGetTestFiles('image') as $image) {
       $image_file = $image_factory->get($image->uri);
-      if ($image_file->getWidth() > $max_resolution) {
+      if ($image_file->getWidth() > $max_dimensions) {
         $image_that_is_too_big = $image;
       }
-      if ($image_file->getWidth() < $min_resolution) {
+      if ($image_file->getWidth() < $min_dimensions) {
         $image_that_is_too_small = $image;
       }
       if ($image_that_is_too_small && $image_that_is_too_big) {
@@ -44,9 +44,9 @@ function testResolution() {
       }
     }
     $this->uploadNodeImage($image_that_is_too_small, $field_name, 'article');
-    $this->assertRaw(t('The specified file %name could not be uploaded.', array('%name' => $image_that_is_too_small->filename)) . ' ' . t('The image is too small; the minimum dimensions are %dimensions pixels.', array('%dimensions' => '50x50')), 'Node save failed when minimum image resolution was not met.');
+    $this->assertRaw(t('The specified file %name could not be uploaded.', array('%name' => $image_that_is_too_small->filename)) . ' ' . t('The image is too small; the minimum dimensions are %dimensions pixels.', array('%dimensions' => '50x50')), 'Node save failed when minimum image dimensions was not met.');
     $this->uploadNodeImage($image_that_is_too_big, $field_name, 'article');
-    $this->assertText(t('The image was resized to fit within the maximum allowed dimensions of 100x100 pixels.'), 'Image exceeding max resolution was properly resized.');
+    $this->assertText(t('The image was resized to fit within the maximum allowed dimensions of 100x100 pixels.'), 'Image exceeding max dimensions was properly resized.');
   }
 
   /**
diff --git a/core/modules/migrate_drupal/config/install/migrate.migration.d6_user_picture_field_instance.yml b/core/modules/migrate_drupal/config/install/migrate.migration.d6_user_picture_field_instance.yml
index ef6c053..7519a18 100644
--- a/core/modules/migrate_drupal/config/install/migrate.migration.d6_user_picture_field_instance.yml
+++ b/core/modules/migrate_drupal/config/install/migrate.migration.d6_user_picture_field_instance.yml
@@ -12,7 +12,7 @@ source:
       file_extensions: 'png gif jpg jpeg'
       alt_field: false
       title_field: false
-      min_resolution: ''
+      min_dimensions: ''
       alt_field_required: false
       title_field_required: false
 process:
@@ -22,7 +22,7 @@ process:
   settings: 'constants/settings'
   'settings/file_directory': file_directory
   'settings/max_filesize': max_filesize
-  'settings/max_resolution': max_resolution
+  'settings/max_dimensions': max_resolution
 destination:
   plugin: entity:field_config
 migration_dependencies:
diff --git a/core/modules/migrate_drupal/src/Plugin/migrate/process/d6/FieldInstanceSettings.php b/core/modules/migrate_drupal/src/Plugin/migrate/process/d6/FieldInstanceSettings.php
index 424bdb0..c8dbfef 100644
--- a/core/modules/migrate_drupal/src/Plugin/migrate/process/d6/FieldInstanceSettings.php
+++ b/core/modules/migrate_drupal/src/Plugin/migrate/process/d6/FieldInstanceSettings.php
@@ -56,8 +56,8 @@ public function transform($value, MigrateExecutable $migrate_executable, Row $ro
         $settings['alt_field_required'] = $widget_settings['custom_alt'];
         $settings['title_field'] = $widget_settings['title'];
         $settings['title_field_required'] = $widget_settings['custom_title'];
-        $settings['max_resolution'] = $widget_settings['max_resolution'];
-        $settings['min_resolution'] = $widget_settings['min_resolution'];
+        $settings['max_dimensions'] = $widget_settings['max_resolution'];
+        $settings['min_dimensions'] = $widget_settings['min_resolution'];
         break;
 
     }
diff --git a/core/modules/migrate_drupal/src/Plugin/migrate/source/d6/UserPictureInstance.php b/core/modules/migrate_drupal/src/Plugin/migrate/source/d6/UserPictureInstance.php
index 03402ce..6c6a0df 100644
--- a/core/modules/migrate_drupal/src/Plugin/migrate/source/d6/UserPictureInstance.php
+++ b/core/modules/migrate_drupal/src/Plugin/migrate/source/d6/UserPictureInstance.php
@@ -29,7 +29,7 @@ public function runQuery() {
         'id' => '',
         'file_directory' => $this->variableGet('user_picture_path', 'pictures'),
         'max_filesize' => $this->variableGet('user_picture_file_size', '30') . 'KB',
-        'max_resolution' => $this->variableGet('user_picture_dimensions', '85x85'),
+        'max_dimensions' => $this->variableGet('user_picture_dimensions', '85x85'),
       )));
   }
 
@@ -40,7 +40,7 @@ public function fields() {
     return array(
       'file_directory' => 'The directory to store images..',
       'max_filesize' => 'The maximum allowed file size in KBs.',
-      'max_resolution' => "The maximum resolution.",
+      'max_dimensions' => "The maximum dimensions.",
     );
   }
 
diff --git a/core/modules/user/src/Tests/UserCreateTest.php b/core/modules/user/src/Tests/UserCreateTest.php
index 9020c5c..af1c986 100644
--- a/core/modules/user/src/Tests/UserCreateTest.php
+++ b/core/modules/user/src/Tests/UserCreateTest.php
@@ -62,8 +62,8 @@ protected function testUserAdd() {
         'max_filesize' => '30 KB',
         'alt_field' => 0,
         'title_field' => 0,
-        'max_resolution' => '85x85',
-        'min_resolution' => '',
+        'max_dimensions' => '85x85',
+        'min_dimensions' => '',
       ),
     ))->save();
 
diff --git a/core/profiles/standard/config/install/field.field.node.article.field_image.yml b/core/profiles/standard/config/install/field.field.node.article.field_image.yml
index f4b1734..4e4e314 100644
--- a/core/profiles/standard/config/install/field.field.node.article.field_image.yml
+++ b/core/profiles/standard/config/install/field.field.node.article.field_image.yml
@@ -11,8 +11,8 @@ settings:
   file_directory: field/image
   file_extensions: 'png gif jpg jpeg'
   max_filesize: ''
-  max_resolution: ''
-  min_resolution: ''
+  max_dimensions: ''
+  min_dimensions: ''
   alt_field: true
   title_field: false
   alt_field_required: false
diff --git a/core/profiles/standard/config/install/field.field.user.user.user_picture.yml b/core/profiles/standard/config/install/field.field.user.user.user_picture.yml
index e1d8b64..3edf833 100644
--- a/core/profiles/standard/config/install/field.field.user.user.user_picture.yml
+++ b/core/profiles/standard/config/install/field.field.user.user.user_picture.yml
@@ -15,8 +15,8 @@ settings:
   max_filesize: '30 KB'
   alt_field: false
   title_field: false
-  max_resolution: 85x85
-  min_resolution: ''
+  max_dimensions: 85x85
+  min_dimensions: ''
   default_image:
     uuid: null
     alt: ''

diff --git a/core/modules/file/src/Tests/ValidatorTest.php b/core/modules/file/src/Tests/ValidatorTest.php
index 304a84c..be4ccf5 100644
--- a/core/modules/file/src/Tests/ValidatorTest.php
+++ b/core/modules/file/src/Tests/ValidatorTest.php
@@ -63,24 +63,24 @@ function testFileValidateIsImage() {
   }
 
   /**
    *  This ensures the resolution of a specific file is within bounds.
    *  The image will be resized if it's too large.
    */
-  function testFileValidateImageResolution() {
+  function testFileValidateImageDimensions() {
     // Non-images.
-    $errors = file_validate_image_resolution($this->non_image);
+    $errors = file_validate_image_dimensions($this->non_image);
     $this->assertEqual(count($errors), 0, 'Should not get any errors for a non-image file.', 'File');
-    $errors = file_validate_image_resolution($this->non_image, '50x50', '100x100');
-    $this->assertEqual(count($errors), 0, 'Do not check the resolution on non files.', 'File');
+    $errors = file_validate_image_dimensions($this->non_image, '50x50', '100x100');
+    $this->assertEqual(count($errors), 0, 'Do not check the dimensions on non files.', 'File');
 
     // Minimum size.
-    $errors = file_validate_image_resolution($this->image);
-    $this->assertEqual(count($errors), 0, 'No errors for an image when there is no minimum or maximum resolution.', 'File');
-    $errors = file_validate_image_resolution($this->image, 0, '200x1');
+    $errors = file_validate_image_dimensions($this->image);
+    $this->assertEqual(count($errors), 0, 'No errors for an image when there is no minimum or maximum dimensions.', 'File');
+    $errors = file_validate_image_dimensions($this->image, 0, '200x1');
     $this->assertEqual(count($errors), 1, 'Got an error for an image that was not wide enough.', 'File');
-    $errors = file_validate_image_resolution($this->image, 0, '1x200');
+    $errors = file_validate_image_dimensions($this->image, 0, '1x200');
     $this->assertEqual(count($errors), 1, 'Got an error for an image that was not tall enough.', 'File');
-    $errors = file_validate_image_resolution($this->image, 0, '200x200');
+    $errors = file_validate_image_dimensions($this->image, 0, '200x200');
     $this->assertEqual(count($errors), 1, 'Small images report an error.', 'File');
 
     // Maximum size.
@@ -89,7 +89,7 @@ function testFileValidateImageResolution() {
       copy('core/misc/druplicon.png', 'temporary://druplicon.png');
       $this->image->setFileUri('temporary://druplicon.png');
 
-      $errors = file_validate_image_resolution($this->image, '10x5');
+      $errors = file_validate_image_dimensions($this->image, '10x5');
       $this->assertEqual(count($errors), 0, 'No errors should be reported when an oversized image can be scaled down.', 'File');
 
       $image = $this->container->get('image.factory')->get($this->image->getFileUri());
@@ -99,14 +99,14 @@ function testFileValidateImageResolution() {
       // Once again, now with negative width and height to force an error.
       copy('core/misc/druplicon.png', 'temporary://druplicon.png');
       $this->image->setFileUri('temporary://druplicon.png');
-      $errors = file_validate_image_resolution($this->image, '-10x-5');
+      $errors = file_validate_image_dimensions($this->image, '-10x-5');
       $this->assertEqual(count($errors), 1, 'An error reported for an oversized image that can not be scaled down.', 'File');
 
       drupal_unlink('temporary://druplicon.png');
     }
     else {
       // TODO: should check that the error is returned if no toolkit is available.
-      $errors = file_validate_image_resolution($this->image, '5x10');
+      $errors = file_validate_image_dimensions($this->image, '5x10');
       $this->assertEqual(count($errors), 1, 'Oversize images that cannot be scaled get an error.', 'File');
     }
   }
@@ -63,24 +63,24 @@ function testFileValidateIsImage() {
 
   /**
-   *  This ensures the resolution of a specific file is within bounds.
+   *  This ensures the dimensions of a specific file is within bounds.
    *  The image will be resized if it's too large.
    */
diff --git a/core/modules/image/src/Plugin/Field/FieldType/ImageItem.php b/core/modules/image/src/Plugin/Field/FieldType/ImageItem.php
index a8bfbb3..963f536 100644
--- a/core/modules/image/src/Plugin/Field/FieldType/ImageItem.php
+++ b/core/modules/image/src/Plugin/Field/FieldType/ImageItem.php
@@ -79,8 +79,8 @@ public static function defaultFieldSettings() {
       'alt_field_required' => 0,
       'title_field' => 0,
       'title_field_required' => 0,
-      'max_resolution' => '',
-      'min_resolution' => '',
+      'max_dimensions' => '',
+      'min_dimensions' => '',
       'default_image' => array(
         'uuid' => NULL,
         'alt' => '',
@@ -199,57 +199,57 @@ public function fieldSettingsForm(array $form, FormStateInterface $form_state) {
 
     $settings = $this->getSettings();
 
-    // Add maximum and minimum resolution settings.
-    $max_resolution = explode('x', $settings['max_resolution']) + array('', '');
-    $element['max_resolution'] = array(
+    // Add maximum and minimum dimensions settings.
+    $max_dimensions = explode('x', $settings['max_dimensions']) + array('', '');
+    $element['max_dimensions'] = array(
       '#type' => 'item',
-      '#title' => t('Maximum image resolution'),
-      '#element_validate' => array(array(get_class($this), 'validateResolution')),
+      '#title' => t('Maximum image dimensions'),
+      '#element_validate' => array(array(get_class($this), 'validateDimensions')),
       '#weight' => 4.1,
       '#field_prefix' => '<div class="container-inline">',
       '#field_suffix' => '</div>',
       '#description' => t('The maximum allowed image size expressed as WIDTH×HEIGHT (e.g. 640×480). Leave blank for no restriction. If a larger image is uploaded, it will be resized to reflect the given width and height. Resizing images on upload will cause the loss of <a href="@url">EXIF data</a> in the image.', array('@url' => 'http://en.wikipedia.org/wiki/Exchangeable_image_file_format')),
     );
-    $element['max_resolution']['x'] = array(
+    $element['max_dimensions']['x'] = array(
       '#type' => 'number',
       '#title' => t('Maximum width'),
       '#title_display' => 'invisible',
-      '#default_value' => $max_resolution[0],
+      '#default_value' => $max_dimensions[0],
       '#min' => 1,
       '#field_suffix' => ' × ',
     );
-    $element['max_resolution']['y'] = array(
+    $element['max_dimensions']['y'] = array(
       '#type' => 'number',
       '#title' => t('Maximum height'),
       '#title_display' => 'invisible',
-      '#default_value' => $max_resolution[1],
+      '#default_value' => $max_dimensions[1],
       '#min' => 1,
       '#field_suffix' => ' ' . t('pixels'),
     );
 
-    $min_resolution = explode('x', $settings['min_resolution']) + array('', '');
-    $element['min_resolution'] = array(
+    $min_dimensions = explode('x', $settings['min_dimensions']) + array('', '');
+    $element['min_dimensions'] = array(
       '#type' => 'item',
-      '#title' => t('Minimum image resolution'),
-      '#element_validate' => array(array(get_class($this), 'validateResolution')),
+      '#title' => t('Minimum image dimensions'),
+      '#element_validate' => array(array(get_class($this), 'validateDimensions')),
       '#weight' => 4.2,
       '#field_prefix' => '<div class="container-inline">',
       '#field_suffix' => '</div>',
       '#description' => t('The minimum allowed image size expressed as WIDTH×HEIGHT (e.g. 640×480). Leave blank for no restriction. If a smaller image is uploaded, it will be rejected.'),
     );
-    $element['min_resolution']['x'] = array(
+    $element['min_dimensions']['x'] = array(
       '#type' => 'number',
       '#title' => t('Minimum width'),
       '#title_display' => 'invisible',
-      '#default_value' => $min_resolution[0],
+      '#default_value' => $min_dimensions[0],
       '#min' => 1,
       '#field_suffix' => ' × ',
     );
-    $element['min_resolution']['y'] = array(
+    $element['min_dimensions']['y'] = array(
       '#type' => 'number',
       '#title' => t('Minimum height'),
       '#title_display' => 'invisible',
-      '#default_value' => $min_resolution[1],
+      '#default_value' => $min_dimensions[1],
       '#min' => 1,
       '#field_suffix' => ' ' . t('pixels'),
     );
@@ -330,16 +330,16 @@ public static function generateSampleValue(FieldDefinitionInterface $field_defin
     $settings = $field_definition->getSettings();
     static $images = array();
 
-    $min_resolution = empty($settings['min_resolution']) ? '100x100' : $settings['min_resolution'];
-    $max_resolution = empty($settings['max_resolution']) ? '600x600' : $settings['max_resolution'];
+    $min_dimensions = empty($settings['min_dimensions']) ? '100x100' : $settings['min_dimensions'];
+    $max_dimensions = empty($settings['max_dimensions']) ? '600x600' : $settings['max_dimensions'];
     $extensions = array_intersect(explode(' ', $settings['file_extensions']), array('png', 'gif', 'jpg', 'jpeg'));
     $extension = array_rand(array_combine($extensions, $extensions));
     // Generate a max of 5 different images.
-    if (!isset($images[$extension][$min_resolution][$max_resolution]) || count($images[$extension][$min_resolution][$max_resolution]) <= 5) {
+    if (!isset($images[$extension][$min_dimensions][$max_dimensions]) || count($images[$extension][$min_dimensions][$max_dimensions]) <= 5) {
       $tmp_file = drupal_tempnam('temporary://', 'generateImage_');
       $destination = $tmp_file . '.' . $extension;
       file_unmanaged_move($tmp_file, $destination, FILE_CREATE_DIRECTORY);
-      if ($path = $random->image(drupal_realpath($destination), $min_resolution, $max_resolution)) {
+      if ($path = $random->image(drupal_realpath($destination), $min_dimensions, $max_dimensions)) {
         $image = File::create();
         $image->setFileUri($path);
         // $image->setOwner($account);
@@ -349,7 +349,7 @@ public static function generateSampleValue(FieldDefinitionInterface $field_defin
         file_prepare_directory($destination_dir, FILE_CREATE_DIRECTORY);
         $destination = $destination_dir . '/' . basename($path);
         $file = file_move($image, $destination, FILE_CREATE_DIRECTORY);
-        $images[$extension][$min_resolution][$max_resolution][$file->id()] = $file;
+        $images[$extension][$min_dimensions][$max_dimensions][$file->id()] = $file;
       }
       else {
         return array();
@@ -357,8 +357,8 @@ public static function generateSampleValue(FieldDefinitionInterface $field_defin
     }
     else {
       // Select one of the images we've already generated for this field.
-      $image_index = array_rand($images[$extension][$min_resolution][$max_resolution]);
-      $file = $images[$extension][$min_resolution][$max_resolution][$image_index];
+      $image_index = array_rand($images[$extension][$min_dimensions][$max_dimensions]);
+      $file = $images[$extension][$min_dimensions][$max_dimensions][$image_index];
     }
 
     list($width, $height) = getimagesize($file->getFileUri());
@@ -373,9 +373,20 @@ public static function generateSampleValue(FieldDefinitionInterface $field_defin
   }
 
   /**
-   * Element validate function for resolution fields.
+   * Backwards compatibility wrapper for validateResolution().
+   *
+   * @deprecated in Drupal 8.0.0, will be removed for Drupal 9.0.0.
+   *
+   * @see validateDimensions()
    */
   public static function validateResolution($element, FormStateInterface $form_state) {
+    return validateDimensions($element, $form_state);
+  }
+
+  /**
+   * Element validate function for dimensions fields.
+   */
+  public static function validateDimensions($element, FormStateInterface $form_state) {
     if (!empty($element['x']['#value']) || !empty($element['y']['#value'])) {
       foreach (array('x', 'y') as $dimension) {
         if (!$element[$dimension]['#value']) {
diff --git a/core/modules/image/src/Plugin/Field/FieldWidget/ImageWidget.php b/core/modules/image/src/Plugin/Field/FieldWidget/ImageWidget.php
index 7b16bd2..4aea5da 100644
--- a/core/modules/image/src/Plugin/Field/FieldWidget/ImageWidget.php
+++ b/core/modules/image/src/Plugin/Field/FieldWidget/ImageWidget.php
@@ -116,9 +116,9 @@ public function formElement(FieldItemListInterface $items, $delta, array $elemen
 
     $field_settings = $this->getFieldSettings();
 
-    // Add upload resolution validation.
-    if ($field_settings['max_resolution'] || $field_settings['min_resolution']) {
-      $element['#upload_validators']['file_validate_image_resolution'] = array($field_settings['max_resolution'], $field_settings['min_resolution']);
+    // Add upload dimensions validation.
+    if ($field_settings['max_dimensions'] || $field_settings['min_dimensions']) {
+      $element['#upload_validators']['file_validate_image_dimensions'] = array($field_settings['max_dimensions'], $field_settings['min_dimensions']);
     }
 
     // If not using custom extension validation, ensure this is an image.
diff --git a/core/modules/image/src/Tests/ImageFieldDisplayTest.php b/core/modules/image/src/Tests/ImageFieldDisplayTest.php
index 4fef5f5..340a626 100644
--- a/core/modules/image/src/Tests/ImageFieldDisplayTest.php
+++ b/core/modules/image/src/Tests/ImageFieldDisplayTest.php
@@ -196,8 +196,8 @@ function testImageFieldSettings() {
       'alt_field' => 1,
       'file_extensions' => $test_image_extension,
       'max_filesize' => '50 KB',
-      'max_resolution' => '100x100',
-      'min_resolution' => '10x10',
+      'max_dimensions' => '100x100',
+      'min_dimensions' => '10x10',
       'title_field' => 1,
     );
     $widget_settings = array(
@@ -205,18 +205,18 @@ function testImageFieldSettings() {
     );
     $field = $this->createImageField($field_name, 'article', array(), $field_settings, $widget_settings);
 
     // Verify that the min/max resolution set on the field are properly
     // extracted, and displayed, on the image field's configuration form.
     $this->drupalGet('admin/structure/types/manage/article/fields/' . $field->id());
-    $this->assertFieldByName('field[settings][max_resolution][x]', '100', 'Expected max resolution X value of 100.');
-    $this->assertFieldByName('field[settings][max_resolution][y]', '100', 'Expected max resolution Y value of 100.');
-    $this->assertFieldByName('field[settings][min_resolution][x]', '10', 'Expected min resolution X value of 10.');
-    $this->assertFieldByName('field[settings][min_resolution][y]', '10', 'Expected min resolution Y value of 10.');
+    $this->assertFieldByName('field[settings][max_dimensions][x]', '100', 'Expected max dimensions X value of 100.');
+    $this->assertFieldByName('field[settings][max_dimensions][y]', '100', 'Expected max dimensions Y value of 100.');
+    $this->assertFieldByName('field[settings][min_dimensions][x]', '10', 'Expected min dimensions X value of 10.');
+    $this->assertFieldByName('field[settings][min_dimensions][y]', '10', 'Expected min dimensions Y value of 10.');
 
     $this->drupalGet('node/add/article');
     $this->assertText(t('50 KB limit.'), 'Image widget max file size is displayed on article form.');
     $this->assertText(t('Allowed types: @extensions.', array('@extensions' => $test_image_extension)), 'Image widget allowed file types displayed on article form.');
-    $this->assertText(t('Images must be larger than 10x10 pixels. Images larger than 100x100 pixels will be resized.'), 'Image widget allowed resolution displayed on article form.');
+    $this->assertText(t('Images must be larger than 10x10 pixels. Images larger than 100x100 pixels will be resized.'), 'Image widget allowed dimensions displayed on article form.');
 
     // We have to create the article first and then edit it because the alt
     // and title fields do not display until the image has been attached.
@@ -205,18 +205,18 @@ function testImageFieldSettings() {
     $field = $this->createImageField($field_name, 'article', array(), $field_settings, $widget_settings);
 
-    // Verify that the min/max resolution set on the field are properly
+    // Verify that the min/max dimensions set on the field are properly
     // extracted, and displayed, on the image field's configuration form.
     $this->drupalGet('admin/structure/types/manage/article/fields/' . $field->id());